# hobo - portal to configure and deploy applications
# Copyright (C) 2015-2022 Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django import forms
from django.utils.translation import gettext_lazy as _

from hobo.applications.models import Application


class GenerateForm(forms.Form):
    number = forms.CharField(label=_('Version Number'), max_length=100)
    notes = forms.CharField(label=_('Version notes'), widget=forms.Textarea, required=False)


class InstallForm(forms.Form):
    bundle = forms.FileField(label=_('Application'))


class MetadataForm(forms.ModelForm):
    class Meta:
        model = Application
        fields = ['name', 'slug', 'description', 'documentation_url', 'icon']

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['icon'].widget.attrs = {'accept': 'image/jpeg,image/png'}

    def clean_icon(self):
        value = self.cleaned_data.get('icon')
        if hasattr(value, 'content_type') and value.content_type not in ('image/jpeg', 'image/png'):
            raise forms.ValidationError(_('The icon must be in JPEG or PNG format.'))
        return value
